@@ -1,41 +1,31 @@
-# -*- coding=utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
-import sys
+from __future__ import annotations
 
 import click
-import crayons
 
 from . import __version__
 from .pythonfinder import Finder
 
 
 @click.command()
-@click.option("--find", default=False, nargs=1, help="Find a specific python version.")
-@click.option("--which", default=False, nargs=1, help="Run the which command.")
+@click.option("--find", nargs=1, help="Find a specific python version.")
+@click.option("--which", nargs=1, help="Run the which command.")
 @click.option("--findall", is_flag=True, default=False, help="Find all python versions.")
 @click.option(
-    "--version", is_flag=True, default=False, help="Display PythonFinder version."
-)
-@click.option(
-    "--ignore-unsupported/--no-unsupported",
+    "--ignore-unsupported",
+    "--no-unsupported",
     is_flag=True,
     default=True,
     envvar="PYTHONFINDER_IGNORE_UNSUPPORTED",
     help="Ignore unsupported python versions.",
 )
-@click.version_option(prog_name="pyfinder", version=__version__)
+@click.version_option(
+    prog_name=click.style("PythonFinder", bold=True),
+    version=click.style(__version__, fg="yellow"),
+)
 @click.pass_context
 def cli(
     ctx, find=False, which=False, findall=False, version=False, ignore_unsupported=True
 ):
-    if version:
-        click.echo(
-            "{0} version {1}".format(
-                crayons.white("PythonFinder", bold=True), crayons.yellow(__version__)
-            )
-        )
-        sys.exit(0)
     finder = Finder(ignore_unsupported=ignore_unsupported)
     if findall:
         versions = [v for v in finder.find_all_python_versions()]
@@ -54,14 +44,14 @@ def cli(
                     ),
                     fg="yellow",
                 )
-            sys.exit(0)
+            ctx.exit()
         else:
             click.secho(
                 "ERROR: No valid python versions found! Check your path and try again.",
                 fg="red",
             )
     if find:
-        click.secho("Searching for python: {0!s}".format(find.strip()), fg="yellow")
+        click.secho(f"Searching for python: {find.strip()!s}", fg="yellow")
         found = finder.find_python_version(find.strip())
         if found:
             py = found.py_version
@@ -70,7 +60,7 @@ def cli(
                 comes_from_path = getattr(comes_from, "path", found.path)
             else:
                 comes_from_path = found.path
-            arch = getattr(py, "architecture", None)
+
             click.secho("Found python at the following locations:", fg="green")
             click.secho(
                 "{py.name!s}: {py.version!s} ({py.architecture!s}) @ {comes_from!s}".format(
@@ -78,22 +68,22 @@ def cli(
                 ),
                 fg="yellow",
             )
-            sys.exit(0)
+            ctx.exit()
         else:
             click.secho("Failed to find matching executable...", fg="yellow")
-            sys.exit(1)
+            ctx.exit(1)
     elif which:
         found = finder.system_path.which(which.strip())
         if found:
-            click.secho("Found Executable: {0}".format(found), fg="white")
-            sys.exit(0)
+            click.secho(f"Found Executable: {found}", fg="white")
+            ctx.exit()
         else:
             click.secho("Failed to find matching executable...", fg="yellow")
-            sys.exit(1)
+            ctx.exit(1)
     else:
         click.echo("Please provide a command", color="red")
-        sys.exit(1)
-    sys.exit()
+        ctx.exit(1)
+    ctx.exit()
 
 
 if __name__ == "__main__":
